@@ -613,7 +613,7 @@ public class CBZip2OutputStream extends OutputStream
      * @throws IOException
      *             if an I/O error occurs in the specified stream.
      * @throws IllegalArgumentException
-     *             if <code>(blockSize < 1) || (blockSize > 9)</code>.
+     *             if <code>(blockSize &lt; 1) || (blockSize &gt; 9)</code>.
      * @throws NullPointerException
      *             if <code>out == null</code>.
      *
@@ -642,6 +642,7 @@ public class CBZip2OutputStream extends OutputStream
     }
 
     /** {@inheritDoc} */
+    @Override
     public void write(final int b) throws IOException {
         if (this.out != null) {
             write0(b);
@@ -718,8 +719,9 @@ public class CBZip2OutputStream extends OutputStream
     }
 
     /**
-     * Overriden to close the stream.
+     * Overridden to close the stream.
      */
+    @Override
     protected void finalize() throws Throwable {
         finish();
         super.finalize();
@@ -743,6 +745,7 @@ public class CBZip2OutputStream extends OutputStream
         }
     }
 
+    @Override
     public void close() throws IOException {
         if (out != null) {
             OutputStream outShadow = this.out;
@@ -751,6 +754,7 @@ public class CBZip2OutputStream extends OutputStream
         }
     }
 
+    @Override
     public void flush() throws IOException {
         OutputStream outShadow = this.out;
         if (outShadow != null) {
@@ -855,6 +859,7 @@ public class CBZip2OutputStream extends OutputStream
         return this.blockSize100k;
     }
 
+    @Override
     public void write(final byte[] buf, int offs, final int len)
         throws IOException {
         if (offs < 0) {
